@@ -8,7 +8,8 @@ export default function PropertyCheckbox(_ref) {
   var value = _ref.value,
       onUpdate = _ref.onUpdate,
       configs = _ref.configs,
-      sourceElement = _ref.sourceElement;
+      sourceElement = _ref.sourceElement,
+      internalState = _ref.internalState;
 
   return React.createElement(
     'table',
@@ -44,5 +45,6 @@ PropertyCheckbox.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
-  sourceElement: PropTypes.object
+  sourceElement: PropTypes.object,
+  internalState: PropTypes.object
 };
\ No newline at end of file
