@@ -341,7 +341,8 @@ var ElementEditor = function (_Component) {
               return _this3.updateProperty(propertyName, value);
             },
             state: appState,
-            sourceElement: _this3.props.element
+            sourceElement: _this3.props.element,
+            internalState: _this3.state
           });
         }),
         React.createElement(
