@@ -73,6 +73,89 @@ export var SELECT_LAYER = 'SELECT_LAYER';
 export var OPEN_LAYER_CONFIGURATOR = 'OPEN_LAYER_CONFIGURATOR';
 export var REMOVE_LAYER = 'REMOVE_LAYER';
 
+//GROUPING ACTIONS
+export var PROJECT_ACTIONS = {
+  NEW_PROJECT: NEW_PROJECT,
+  LOAD_PROJECT: LOAD_PROJECT,
+  SAVE_PROJECT: SAVE_PROJECT,
+  OPEN_CATALOG: OPEN_CATALOG,
+  SELECT_TOOL_EDIT: SELECT_TOOL_EDIT,
+  UNSELECT_ALL: UNSELECT_ALL,
+  SET_PROPERTIES: SET_PROPERTIES,
+  SET_ITEMS_ATTRIBUTES: SET_ITEMS_ATTRIBUTES,
+  SET_LINES_ATTRIBUTES: SET_LINES_ATTRIBUTES,
+  SET_HOLES_ATTRIBUTES: SET_HOLES_ATTRIBUTES,
+  REMOVE: REMOVE,
+  UNDO: UNDO,
+  ROLLBACK: ROLLBACK,
+  SET_PROJECT_PROPERTIES: SET_PROJECT_PROPERTIES,
+  OPEN_PROJECT_CONFIGURATOR: OPEN_PROJECT_CONFIGURATOR,
+  INIT_CATALOG: INIT_CATALOG
+};
+
+export var VIEWER2D_ACTIONS = {
+  SELECT_TOOL_ZOOM_IN: SELECT_TOOL_ZOOM_IN,
+  SELECT_TOOL_ZOOM_OUT: SELECT_TOOL_ZOOM_OUT,
+  SELECT_TOOL_PAN: SELECT_TOOL_PAN,
+  UPDATE_2D_CAMERA: UPDATE_2D_CAMERA
+};
+
+export var VIEWER3D_ACTIONS = {
+  SELECT_TOOL_3D_VIEW: SELECT_TOOL_3D_VIEW,
+  SELECT_TOOL_3D_FIRST_PERSON: SELECT_TOOL_3D_FIRST_PERSON
+};
+
+export var ITEMS_ACTIONS = {
+  SELECT_TOOL_DRAWING_ITEM: SELECT_TOOL_DRAWING_ITEM,
+  UPDATE_DRAWING_ITEM: UPDATE_DRAWING_ITEM,
+  END_DRAWING_ITEM: END_DRAWING_ITEM,
+  BEGIN_DRAGGING_ITEM: BEGIN_DRAGGING_ITEM,
+  UPDATE_DRAGGING_ITEM: UPDATE_DRAGGING_ITEM,
+  END_DRAGGING_ITEM: END_DRAGGING_ITEM,
+  BEGIN_ROTATING_ITEM: BEGIN_ROTATING_ITEM,
+  UPDATE_ROTATING_ITEM: UPDATE_ROTATING_ITEM,
+  END_ROTATING_ITEM: END_ROTATING_ITEM
+};
+
+export var HOLE_ACTIONS = {
+  SELECT_HOLE: SELECT_HOLE,
+  SELECT_TOOL_DRAWING_HOLE: SELECT_TOOL_DRAWING_HOLE,
+  UPDATE_DRAWING_HOLE: UPDATE_DRAWING_HOLE,
+  END_DRAWING_HOLE: END_DRAWING_HOLE,
+  BEGIN_DRAGGING_HOLE: BEGIN_DRAGGING_HOLE,
+  UPDATE_DRAGGING_HOLE: UPDATE_DRAGGING_HOLE,
+  END_DRAGGING_HOLE: END_DRAGGING_HOLE
+};
+
+export var LINE_ACTIONS = {
+  SELECT_LINE: SELECT_LINE,
+  SELECT_TOOL_DRAWING_LINE: SELECT_TOOL_DRAWING_LINE,
+  BEGIN_DRAWING_LINE: BEGIN_DRAWING_LINE,
+  UPDATE_DRAWING_LINE: UPDATE_DRAWING_LINE,
+  END_DRAWING_LINE: END_DRAWING_LINE,
+  BEGIN_DRAGGING_LINE: BEGIN_DRAGGING_LINE,
+  UPDATE_DRAGGING_LINE: UPDATE_DRAGGING_LINE,
+  END_DRAGGING_LINE: END_DRAGGING_LINE
+};
+
+export var AREA_ACTIONS = {
+  SELECT_AREA: SELECT_AREA
+};
+
+export var SCENE_ACTIONS = {
+  ADD_LAYER: ADD_LAYER,
+  SET_LAYER_PROPERTIES: SET_LAYER_PROPERTIES,
+  SELECT_LAYER: SELECT_LAYER,
+  OPEN_LAYER_CONFIGURATOR: OPEN_LAYER_CONFIGURATOR,
+  REMOVE_LAYER: REMOVE_LAYER
+};
+
+export var VERTEX_ACTIONS = {
+  BEGIN_DRAGGING_VERTEX: BEGIN_DRAGGING_VERTEX,
+  UPDATE_DRAGGING_VERTEX: UPDATE_DRAGGING_VERTEX,
+  END_DRAGGING_VERTEX: END_DRAGGING_VERTEX
+};
+
 //MODES
 export var MODE_IDLE = 'IDLE';
 export var MODE_2D_ZOOM_IN = 'MODE_2D_ZOOM_IN';
@@ -95,7 +178,7 @@ export var MODE_VIEWING_CATALOG = 'MODE_VIEWING_CATALOG';
 export var MODE_CONFIGURING_PROJECT = 'MODE_CONFIGURING_PROJECT';
 export var MODE_CONFIGURING_LAYER = 'MODE_CONFIGURING_LAYER';
 
-//unit
+//UNITS
 export var UNIT_MILLIMETER = 'mm';
 export var UNIT_CENTIMETER = 'cm';
 export var UNIT_METER = 'm';
