@@ -225,32 +225,34 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
       var intersection = Geometry.intersectionFromTwoLineSegment({ x: x0, y: y0 }, { x: x1, y: y1 }, v0, v1);
 
       if (intersection.type === "colinear") {
-        if (!oldHoles) {
-          oldHoles = [];
-        }
-
-        var orderedVertices = Geometry.orderVertices([{ x: x0, y: y0 }, { x: x1, y: y1 }]);
-
-        layer.lines.get(line.id).holes.forEach(function (holeID) {
-          var hole = layer.holes.get(holeID);
-          var oldLineLength = Geometry.pointsDistance(v0.x, v0.y, v1.x, v1.y);
-
-          var alpha = Math.atan2(orderedVertices[1].y - orderedVertices[0].y, orderedVertices[1].x - orderedVertices[0].x);
-
-          var offset = hole.offset;
-
-          if (orderedVertices[1].x === line.vertices.get(1).x && orderedVertices[1].y === line.vertices(1).y) {
-            offset = 1 - offset;
+        (function () {
+          if (!oldHoles) {
+            oldHoles = [];
           }
 
-          var xp = oldLineLength * offset * Math.cos(alpha) + v0.x;
-          var yp = oldLineLength * offset * Math.sin(alpha) + v0.y;
+          var orderedVertices = Geometry.orderVertices([{ x: x0, y: y0 }, { x: x1, y: y1 }]);
 
-          oldHoles.push({ hole: hole, offsetPosition: { x: xp, y: yp } });
-        });
+          layer.lines.get(line.id).holes.forEach(function (holeID) {
+            var hole = layer.holes.get(holeID);
+            var oldLineLength = Geometry.pointsDistance(v0.x, v0.y, v1.x, v1.y);
 
-        removeLine(layer, line.id);
-        points.push(v0, v1);
+            var alpha = Math.atan2(orderedVertices[1].y - orderedVertices[0].y, orderedVertices[1].x - orderedVertices[0].x);
+
+            var offset = hole.offset;
+
+            if (orderedVertices[1].x === line.vertices.get(1).x && orderedVertices[1].y === line.vertices(1).y) {
+              offset = 1 - offset;
+            }
+
+            var xp = oldLineLength * offset * Math.cos(alpha) + v0.x;
+            var yp = oldLineLength * offset * Math.sin(alpha) + v0.y;
+
+            oldHoles.push({ hole: hole, offsetPosition: { x: xp, y: yp } });
+          });
+
+          removeLine(layer, line.id);
+          points.push(v0, v1);
+        })();
       }
 
       if (intersection.type === "intersecting" && !hasCommonEndpoint) {
@@ -515,6 +517,10 @@ export function removeArea(layer, areaID) {
   return { layer: layer, area: area };
 }
 
+var sameSet = function sameSet(set1, set2) {
+  return set1.size == set2.size && set1.isSuperset(set2) && set1.isSubset(set2);
+};
+
 export function detectAndUpdateAreas(layer, catalog) {
 
   var verticesArray = []; //array with vertices coords
@@ -545,10 +551,6 @@ export function detectAndUpdateAreas(layer, catalog) {
     }));
   });
 
-  var sameSet = function sameSet(set1, set2) {
-    return set1.isSuperset(set2) && set1.isSubset(set2) && set1.size === set2.size;
-  };
-
   layer = layer.withMutations(function (layer) {
     //remove areas
     layer.areas.forEach(function (area) {
@@ -559,15 +561,13 @@ export function detectAndUpdateAreas(layer, catalog) {
     });
 
     //add new areas
-    var layerVertices = layer.vertices;
     innerCyclesByVerticesID.forEach(function (cycle) {
       var areaInUse = layer.areas.some(function (area) {
         return sameSet(area.vertices, cycle);
       });
       if (!areaInUse) {
         var areaVerticesCoords = cycle.map(function (vertexId) {
-          var vertex = layerVertices.get(vertexId);
-          return { x: vertex.x, y: vertex.y };
+          return layer.vertices.get(vertexId);
         });
         addArea(layer, 'area', areaVerticesCoords, catalog);
       }
