@@ -4,7 +4,7 @@ import FormLabel from '../../components/style/form-label'
 const tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px" };
 const firstTdStyle = { width: '6em' };
 
-export default function PropertyCheckbox({value, onUpdate, configs, sourceElement}) {
+export default function PropertyCheckbox({value, onUpdate, configs, sourceElement, internalState}) {
   return (
     <table className="PropertyCheckbox" style={tableStyle}>
       <tbody>
@@ -23,5 +23,6 @@ PropertyCheckbox.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
-  sourceElement: PropTypes.object
+  sourceElement: PropTypes.object,
+  internalState: PropTypes.object
 };
