@@ -6,7 +6,7 @@ import FormLabel from '../../components/style/form-label';
 const tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px" };
 const firstTdStyle = { width: '6em' };
 
-export default function PropertyEnum({value, onUpdate, configs, sourceElement}) {
+export default function PropertyEnum({value, onUpdate, configs, sourceElement, internalState}) {
   return (
     <table className="PropertyEnum" style={tableStyle}>
       <tbody>
@@ -29,5 +29,6 @@ PropertyEnum.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
-  sourceElement: PropTypes.object
+  sourceElement: PropTypes.object,
+  internalState: PropTypes.object
 };
