@@ -1,6 +1,6 @@
 import React, {PropTypes} from 'react';
 
-export default function PropertyHidden({value, onUpdate, configs, sourceElement}) {
+export default function PropertyHidden({value, onUpdate, configs, sourceElement, internalState}) {
   return null
 }
 
@@ -8,5 +8,6 @@ PropertyHidden.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
-  sourceElement: PropTypes.object
+  sourceElement: PropTypes.object,
+  internalState: PropTypes.object
 };
