@@ -5,7 +5,7 @@ import FormNumberInput from '../../components/style/form-number-input';
 const tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px" };
 const firstTdStyle = { width: '6em' };
 
-export default function PropertyNumber({value, onUpdate, configs, sourceElement}) {
+export default function PropertyNumber({value, onUpdate, configs, sourceElement, internalState}) {
 
   let update = (value) => {
     let number = parseFloat(value);
@@ -39,5 +39,6 @@ PropertyNumber.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
-  sourceElement: PropTypes.object
+  sourceElement: PropTypes.object,
+  internalState: PropTypes.object
 };
