@@ -5,7 +5,7 @@ import FormTextInput from '../../components/style/form-text-input';
 const tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px" };
 const firstTdStyle = { width: '6em' };
 
-export default function PropertyString({value, onUpdate, configs, sourceElement}) {
+export default function PropertyString({value, onUpdate, configs, sourceElement, internalState}) {
   return (
     <table className="PropertyString" style={tableStyle}>
       <tbody>
@@ -26,5 +26,6 @@ PropertyString.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
-  sourceElement: PropTypes.object
+  sourceElement: PropTypes.object,
+  internalState: PropTypes.object
 };
