@@ -73,6 +73,89 @@ export const SELECT_LAYER = 'SELECT_LAYER';
 export const OPEN_LAYER_CONFIGURATOR = 'OPEN_LAYER_CONFIGURATOR';
 export const REMOVE_LAYER = 'REMOVE_LAYER';
 
+//GROUPING ACTIONS
+export const PROJECT_ACTIONS = {
+  NEW_PROJECT,
+  LOAD_PROJECT,
+  SAVE_PROJECT,
+  OPEN_CATALOG,
+  SELECT_TOOL_EDIT,
+  UNSELECT_ALL,
+  SET_PROPERTIES,
+  SET_ITEMS_ATTRIBUTES,
+  SET_LINES_ATTRIBUTES,
+  SET_HOLES_ATTRIBUTES,
+  REMOVE,
+  UNDO,
+  ROLLBACK,
+  SET_PROJECT_PROPERTIES,
+  OPEN_PROJECT_CONFIGURATOR,
+  INIT_CATALOG
+};
+
+export const VIEWER2D_ACTIONS = {
+  SELECT_TOOL_ZOOM_IN,
+  SELECT_TOOL_ZOOM_OUT,
+  SELECT_TOOL_PAN,
+  UPDATE_2D_CAMERA
+};
+
+export const VIEWER3D_ACTIONS = {
+  SELECT_TOOL_3D_VIEW,
+  SELECT_TOOL_3D_FIRST_PERSON
+};
+
+export const ITEMS_ACTIONS = {
+  SELECT_TOOL_DRAWING_ITEM,
+  UPDATE_DRAWING_ITEM,
+  END_DRAWING_ITEM,
+  BEGIN_DRAGGING_ITEM,
+  UPDATE_DRAGGING_ITEM,
+  END_DRAGGING_ITEM,
+  BEGIN_ROTATING_ITEM,
+  UPDATE_ROTATING_ITEM,
+  END_ROTATING_ITEM
+};
+
+export const HOLE_ACTIONS = {
+  SELECT_HOLE,
+  SELECT_TOOL_DRAWING_HOLE,
+  UPDATE_DRAWING_HOLE,
+  END_DRAWING_HOLE,
+  BEGIN_DRAGGING_HOLE,
+  UPDATE_DRAGGING_HOLE,
+  END_DRAGGING_HOLE
+};
+
+export const LINE_ACTIONS = {
+  SELECT_LINE,
+  SELECT_TOOL_DRAWING_LINE,
+  BEGIN_DRAWING_LINE,
+  UPDATE_DRAWING_LINE,
+  END_DRAWING_LINE,
+  BEGIN_DRAGGING_LINE,
+  UPDATE_DRAGGING_LINE,
+  END_DRAGGING_LINE
+}
+
+export const AREA_ACTIONS = {
+  SELECT_AREA
+}
+
+export const SCENE_ACTIONS = {
+  ADD_LAYER,
+  SET_LAYER_PROPERTIES,
+  SELECT_LAYER,
+  OPEN_LAYER_CONFIGURATOR,
+  REMOVE_LAYER
+};
+
+export const VERTEX_ACTIONS = {
+  BEGIN_DRAGGING_VERTEX,
+  UPDATE_DRAGGING_VERTEX,
+  END_DRAGGING_VERTEX
+};
+
 //MODES
 export const MODE_IDLE = 'IDLE';
 export const MODE_2D_ZOOM_IN = 'MODE_2D_ZOOM_IN';
@@ -95,8 +178,7 @@ export const MODE_VIEWING_CATALOG = 'MODE_VIEWING_CATALOG';
 export const MODE_CONFIGURING_PROJECT = 'MODE_CONFIGURING_PROJECT';
 export const MODE_CONFIGURING_LAYER = 'MODE_CONFIGURING_LAYER';
 
-
-//unit
+//UNITS
 export const UNIT_MILLIMETER = 'mm';
 export const UNIT_CENTIMETER = 'cm';
 export const UNIT_METER = 'm';
